/*
 *
 */
#include "stdafx.h"
#include "PanViewerView.h"
#include "PanFactory.h"

SIZE
CPanViewerView::OpenEffect(HWND hWnd, PTSTR fName, CPerfData* pData, LPTSTR& effectName)
{
    RECT r;
    SIZE sz = {0,0};
    
    // Free up the current image/effect.
    if (m_image) {
        delete m_image;
        m_image = NULL;
    }
    m_image = m_imgFact->OpenEffect(hWnd,fName,pData,effectName);

    if (m_image) {
        m_image->SetFileName(fName);

        ::GetClientRect(m_image->GetHWND(), &r);
        sz.cx = r.right - r.left;
        sz.cy = r.bottom - r.top;
    }
    return sz;
}

SIZE
CPanViewerView::OpenEffect(HWND hWnd, REFCLSID clsid, PTSTR progID, CPerfData* pData)
{
    RECT r;
    SIZE sz = {0,0};

    if (m_image) {
        delete m_image;
    }
    m_image = m_imgFact->OpenEffect(hWnd,clsid,progID,pData);

    if (m_image) {
        ::GetClientRect(m_image->GetHWND(), &r);
        sz.cx = r.right - r.left;
        sz.cy = r.bottom - r.top;
    }
    return sz;
}

//
// METHOD:      void CloseEffect()
//
// PURPOSE:     Shut down the current effect, removing its UI &
//              unloading the component.
// 
void
CPanViewerView::CloseEffect()
{
    if (m_image) {
        delete m_image;
        m_image = NULL;
    }
}

void CPanViewerView::SaveEffect(BOOL bSaveAs)
{
    if (!m_image) 
        return;

    if (bSaveAs || m_image->GetFileName() == NULL) {
        // Time to pop up the FileOpen dialog.
        OPENFILENAME ofn;
        TCHAR pstr[MAX_PATH];
        int i = 0;

	    
        // This *has* to be zero-terminated before passing it in
        pstr[0] = TEXT('\0');
	      
        ofn.lStructSize       = sizeof(OPENFILENAME);
        ofn.hwndOwner         = GetDesktopWindow();
        ofn.lpstrFilter       = TEXT("Pan Files (*.pan)\0*.PAN\0All Files (*.*)\0*.*\0");
        ofn.lpstrCustomFilter = NULL;
        ofn.nFilterIndex      = 1;
        ofn.lpstrFile         = (LPTSTR)pstr;
        ofn.nMaxFile          = MAX_PATH;
        ofn.lpstrInitialDir   = NULL;
        ofn.lpstrTitle        = NULL;
        ofn.lpstrFileTitle    = NULL;
        ofn.lpstrDefExt       = NULL;
        ofn.Flags             = OFN_FILEMUSTEXIST | OFN_READONLY | OFN_PATHMUSTEXIST;

        // We're now ready to ask for the selection:
        if ( !GetSaveFileName(&ofn) ) {
            TCHAR		sErrMsg[256];
            long		errMsg;
	    
            errMsg = CommDlgExtendedError();
	    
            if (errMsg == 0) { // Did the user Cancel?
                return;
            } else {
                _stprintf(sErrMsg,TEXT("Error %d returned from GetOpenFileName()"), errMsg);
                MessageBox(sErrMsg, TEXT("FileOpen"), MB_OK);
                return;
            } 
        } else {
            // make sure the .pan extension gets added
            // (Note: this also overwrites any other extension
            // the user typed in.)
            PathRenameExtension(pstr, TEXT(".pan"));
            m_image->SetFileName(pstr);
        }
    }
    m_image->Save();
}
